@@ -25,7 +25,7 @@ from .app_settings import (
     EVEUNIVERSE_USE_EVESKINSERVER,
 )
 from .constants import EveCategoryId, EveGroupId
-from .core import eveimageserver, evemicros, eveskinserver
+from .core import dotlan, eveimageserver, eveitems, evemicros, eveskinserver, evewho
 from .managers import (
     EveAsteroidBeltManager,
     EveEntityManager,
@@ -482,6 +482,29 @@ class EveEntity(EveUniverseEntityModel):
 
         return False
 
+    @property
+    def profile_url(self) -> str:
+        """URL to default third party website with profile info about this entity.
+
+        Supported for:
+        alliance, character, corporation, faction, region, solar system, type
+        """
+        if self.is_alliance:
+            return dotlan.alliance_url(self.name)
+        elif self.is_character:
+            return evewho.character_url(self.id)
+        elif self.is_corporation:
+            return dotlan.corporation_url(self.name)
+        elif self.is_faction:
+            return dotlan.faction_url(self.name)
+        elif self.is_region:
+            return dotlan.region_url(self.name)
+        elif self.is_solar_system:
+            return dotlan.solar_system_url(self.name)
+        elif self.is_type:
+            return eveitems.type_url(self.id)
+        return ""
+
     def is_category(self, category: str) -> bool:
         """returns True if this entity has the given category, else False"""
         return category in self._CATEGORIES and self.category == category
@@ -826,6 +849,11 @@ class EveFaction(EveUniverseEntityModel):
         field_mappings = {"eve_solar_system": "solar_system_id"}
         load_order = 210
 
+    @property
+    def profile_url(self) -> str:
+        """URL to default third party website with profile info about this entity."""
+        return dotlan.faction_url(self.name)
+
     def logo_url(self, size=EveUniverseEntityModel.DEFAULT_ICON_SIZE) -> str:
         """returns an image URL for this faction
 
@@ -1039,6 +1067,11 @@ class EveRegion(EveUniverseEntityModel):
         children = {"constellations": "EveConstellation"}
         load_order = 190
 
+    @property
+    def profile_url(self) -> str:
+        """URL to default third party website with profile info about this entity."""
+        return dotlan.region_url(self.name)
+
     @classmethod
     def eve_entity_category(cls) -> str:
         return EveEntity.CATEGORY_REGION
@@ -1052,7 +1085,7 @@ class EveSolarSystem(EveUniverseEntityModel):
 
         PLANETS = "planets"  #:
         STARGATES = "stargates"  #:
-        STARS = "stars"  #
+        STARS = "stars"  #:
         STATIONS = "stations"  #:
 
     eve_constellation = models.ForeignKey(
@@ -1101,6 +1134,11 @@ class EveSolarSystem(EveUniverseEntityModel):
     )
     NearestCelestial.__doc__ = "Container for a nearest celestial"
 
+    @property
+    def profile_url(self) -> str:
+        """URL to default third party website with profile info about this entity."""
+        return dotlan.solar_system_url(self.name)
+
     @property
     def is_high_sec(self) -> bool:
         """returns True if this solar system is in high sec, else False"""
@@ -1405,7 +1443,7 @@ class EveType(EveUniverseEntityModel):
 
         DOGMAS = "dogmas"  #:
         GRAPHICS = "graphics"  #:
-        MARKET_GROUPS = "market_groups"  #
+        MARKET_GROUPS = "market_groups"  #:
         TYPE_MATERIALS = "type_materials"  #:
 
     capacity = models.FloatField(default=None, null=True)
@@ -1459,6 +1497,11 @@ class EveType(EveUniverseEntityModel):
         }
         load_order = 134
 
+    @property
+    def profile_url(self) -> str:
+        """URL to display this type on the default third party webpage."""
+        return eveitems.type_url(self.id)
+
     class IconVariant(enum.Enum):
         """Variant of icon to produce with `icon_url()`"""
 
